@@ -4,7 +4,7 @@ namespace React\Promise;
 
 class SimpleFulfilledTestThenable
 {
-    public function then(callable $onFulfilled = null, callable $onRejected = null): self
+    public function then(?callable $onFulfilled = null, ?callable $onRejected = null): self
     {
         if ($onFulfilled) {
             $onFulfilled('foo');
